@@ -64,7 +64,7 @@ module OEmbed
       # will be called (in order) with the URL.
       #
       # A common example:
-      #  OEmbed::Providers.register_fallback(OEmbed::ProviderDiscovery, OEmbed::Providers::OohEmbed)
+      #  OEmbed::Providers.register_fallback(OEmbed::ProviderDiscovery, OEmbed::Providers::Noembed)
       def register_fallback(*providers)
         @@fallback += providers
       end
@@ -143,6 +143,12 @@ module OEmbed
     Youtube << "https://*.youtu.be/*"
     add_official_provider(Youtube)
 
+    # Provider for codepen.io
+    CodePen = OEmbed::Provider.new("https://codepen.io/api/oembed")
+    CodePen << "http://codepen.io/*"
+    CodePen << "https://codepen.io/*"
+    add_official_provider(CodePen)
+
     # Provider for flickr.com
     Flickr = OEmbed::Provider.new("https://www.flickr.com/services/oembed/")
     Flickr << "http://*.flickr.com/*"
@@ -170,8 +176,9 @@ module OEmbed
     add_official_provider(Revision3)
 
     # Provider for hulu.com
-    Hulu = OEmbed::Provider.new("http://www.hulu.com/api/oembed.{format}")
+    Hulu = OEmbed::Provider.new("https://www.hulu.com/api/oembed.{format}")
     Hulu << "http://www.hulu.com/watch/*"
+    Hulu << "https://www.hulu.com/watch/*"
     add_official_provider(Hulu)
 
     # Provider for vimeo.com
@@ -239,12 +246,24 @@ module OEmbed
     Yfrog << "http://yfrog.com/*"
     add_official_provider(Yfrog)
 
+    # Provider for Giphy
+    Giphy = OEmbed::Provider.new("http://giphy.com/services/oembed")
+    Giphy << "http://giphy.com/*"
+    Giphy << "https://giphy.com/*"
+    add_official_provider(Giphy)
+
     # Provider for imgur.com
     Imgur = OEmbed::Provider.new("https://api.imgur.com/oembed.{format}")
     Imgur << "https://*.imgur.com/gallery/*"
     Imgur << "http://*.imgur.com/gallery/*"
     add_official_provider(Imgur)
 
+    # Provider for Kickstarter
+    Kickstarter = OEmbed::Provider.new("https://www.kickstarter.com/services/oembed")
+    Kickstarter << "http://www.kickstarter.com/projects/*"
+    Kickstarter << "https://www.kickstarter.com/projects/*"
+    add_official_provider(Kickstarter)
+
     # provider for mlg-tv
     # http://tv.majorleaguegaming.com/oembed
     MlgTv = OEmbed::Provider.new("http://tv.majorleaguegaming.com/oembed")
@@ -285,6 +304,13 @@ module OEmbed
     Scribd << "http://*.scribd.com/*"
     add_official_provider(Scribd)
 
+    # Provider for speakerdeck.com
+    # https://speakerdeck.com/faq#oembed
+    SpeakerDeck = OEmbed::Provider.new("https://speakerdeck.com/oembed.json")
+    SpeakerDeck << "http://speakerdeck.com/*/*"
+    SpeakerDeck << "https://speakerdeck.com/*/*"
+    add_official_provider(SpeakerDeck)
+
     # Provider for movieclips.com
     MovieClips = OEmbed::Provider.new("http://movieclips.com/services/oembed/")
     MovieClips << "http://movieclips.com/watch/*/*/"
@@ -320,6 +346,12 @@ module OEmbed
     Skitch << "https://*.skitch.com/*"
     add_official_provider(Skitch)
 
+    # Provider for TED
+    Ted = OEmbed::Provider.new("https://www.ted.com/talks/oembed.{format}")
+    Ted << "http://*.ted.com/talks/*"
+    Ted << "https://*.ted.com/talks/*"
+    add_official_provider(Ted)
+
     # Provider for tumblr.com
     Tumblr = OEmbed::Provider.new("http://www.tumblr.com/oembed/1.0/", :json)
     Tumblr << "http://*.tumblr.com/post/*"
@@ -378,6 +410,17 @@ module OEmbed
     OohEmbed << %r{http://yfrog.(com|ru|com.tr|it|fr|co.il|co.uk|com.pl|pl|eu|us)/(.*?)} # image & video hosting
     OohEmbed << "http://*.youtube.com/watch*"
 
+    # Provider for noembed.com, which is a provider aggregator. See
+    # OEmbed::Providers::Noembed.urls for a full list of supported url schemas.
+    # https://noembed.com/#supported-sites
+    Noembed = OEmbed::Provider.new("https://noembed.com/embed")
+    # Add all known URL regexps for Noembed.
+    # To update this list run `rake oembed:update_noembed`
+    YAML.load_file(File.join(File.dirname(__FILE__), "/providers/noembed_urls.yml")).each do |url|
+      Noembed << Regexp.new(url)
+    end
+    add_official_provider(Noembed, :aggregators)
+
     # Provider for Embedly.com, which is a provider aggregator. See
     # OEmbed::Providers::Embedly.urls for a full list of supported url schemas.
     # http://embed.ly/docs/endpoints/1/oembed
